from lannerpsp import PoE

# Get PoE information.
poe_info = PoE.get_info()

# Get the number of PoE ports on IIoT-I530:
print(poe_info.number_of_poe_ports)  # It should print 6.

# Get the power status of all PoE ports on IIoT-I530:
print(poe_info.power_status)

# Use PoE port-1:
poe1 = PoE(1)

# Enable the PoE port-1 power (power on by auto):
poe1.enable()

# Get the PoE port-1 power status:
print(poe1.get_power_status())  # It should print True.

# Disable the PoE port-1 power (power off):
poe1.disable()

# Get the PoE port-1 power status:
print(poe1.get_power_status())  # It should print False.



from lannerpsp import GPIO

gpio = GPIO()

# Get GPIO information.
gpio_info = gpio.get_info()

# Get the number of GPI/DI pins on LEC-2290:
print(gpio_info.number_of_di_pins)  # It should print 8.

# Get the number of GPO/DO pins on LEC-2290:
print(gpio_info.number_of_do_pins)  # It should print 8.

# Get GPI/DI status (LSB is DI_0).
print(gpio.get_digital_in())

# Set the values of (DO_7 to DO_0) to (1101 0011) signal,
# you can use your preferred integer representation (LSB is DO_0).
# 1. Use binary integer:
gpio.set_digital_out(0b11010011)
# 2. Use octal integer:
gpio.set_digital_out(0o323)
# 3. Use decimal integer:
gpio.set_digital_out(211)
# 4. Use hexadecimal integer:
gpio.set_digital_out(0xD3)
